@@ -86,6 +86,10 @@ int main ( int argc, char** argv )
     }
 
     try {
+        // High DPI support
+#if QT_VERSION >= QT_VERSION_CHECK(5,1,0)
+        QGuiApplication::setAttribute( Qt::AA_UseHighDpiPixmaps, true );
+#endif
 #if QT_VERSION >= QT_VERSION_CHECK(5,6,0)
         QGuiApplication::setAttribute( Qt::AA_EnableHighDpiScaling );
 #endif
