@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -34,7 +34,7 @@ class CommandDeleteTask : public CharmCommand
 
 public:
     explicit CommandDeleteTask( const Task&, QObject* parent = nullptr );
-    ~CommandDeleteTask();
+    ~CommandDeleteTask() override;
 
     bool prepare() override;
     bool execute( ControllerInterface* ) override;
@@ -42,7 +42,7 @@ public:
 
 private:
     Task m_task;
-    bool m_success;
+    bool m_success = false;
 };
 
 #endif
