@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -33,14 +33,14 @@ class CommandExportToXml : public CharmCommand
     Q_OBJECT
 public:
     explicit CommandExportToXml( QString filename, QObject* parent );
-    ~CommandExportToXml();
+    ~CommandExportToXml() override;
 
     bool prepare() override;
     bool execute( ControllerInterface* ) override;
     bool finalize() override;
 
 private:
-    bool m_error;
+    bool m_error = false;
     QString m_errorString;
     QString m_filename;
 };
