@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -36,7 +36,7 @@ class CommandMakeAndActivateEvent : public CharmCommand
 
 public:
     explicit CommandMakeAndActivateEvent( const Task&, QObject* parent );
-    ~CommandMakeAndActivateEvent();
+    ~CommandMakeAndActivateEvent() override;
 
     bool prepare() override;
     bool execute( ControllerInterface* ) override;
