@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2008-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2008-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -33,7 +33,7 @@ class CommandSetAllTasks : public CharmCommand
 
 public:
     explicit CommandSetAllTasks( const TaskList&, QObject* parent );
-    ~CommandSetAllTasks();
+    ~CommandSetAllTasks() override;
 
     bool prepare() override;
     bool execute( ControllerInterface* ) override;
@@ -41,7 +41,7 @@ public:
 
 private:
     TaskList m_tasks;
-    bool m_success;
+    bool m_success = false;
 };
 
 #endif
