@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2008-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2008-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Jesper Pedersen <jesper.pedersen@kdab.com>
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
@@ -29,12 +29,18 @@
 
 #include <QTimer>
 
+#if defined(Q_OS_UNIX) && !defined(Q_OS_OSX)
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+#include <xcb/xcb.h>
+#endif
+#endif
+
 class X11IdleDetector : public IdleDetector
 {
     Q_OBJECT
 public:
     explicit X11IdleDetector( QObject* parent );
-    static bool idleCheckPossible();
+    bool idleCheckPossible();
 
 protected:
     void onIdlenessDurationChanged();
@@ -45,6 +51,12 @@ private slots:
 private:
     QDateTime m_heartbeat;
     QTimer m_timer;
+#if defined(Q_OS_UNIX) && !defined(Q_OS_OSX)
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+    xcb_connection_t* m_connection;
+    xcb_screen_t* m_screen;
+#endif
+#endif
 };
 
 
