@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -25,6 +25,7 @@
 #include "ActivityReport.h"
 #include "ApplicationCore.h"
 #include "DateEntrySyncer.h"
+#include "Data.h"
 #include "SelectTaskDialog.h"
 #include "ViewHelpers.h"
 
@@ -39,14 +40,12 @@
 #include <QTimer>
 #include <QtAlgorithms>
 #include <QUrl>
-#include <QDebug>
 
 #include "ui_ActivityReportConfigurationDialog.h"
 
 ActivityReportConfigurationDialog::ActivityReportConfigurationDialog( QWidget* parent )
     : ReportConfigurationDialog( parent )
     , m_ui( new Ui::ActivityReportConfigurationDialog )
-    , m_rootTask( 0 )
 {
     setWindowTitle( tr( "Activity Report" ) );
 
@@ -60,16 +59,14 @@ ActivityReportConfigurationDialog::ActivityReportConfigurationDialog( QWidget* p
     connect( m_ui->buttonBox, SIGNAL(rejected()), this, SLOT(reject()) );
     connect( m_ui->comboBox, SIGNAL(currentIndexChanged(int)),
              SLOT(slotTimeSpanSelected(int)) );
-    connect( m_ui->checkBoxSubTasksOnly, SIGNAL(toggled(bool)),
-             SLOT(slotCheckboxSubtasksOnlyChecked(bool)) );
-    connect( m_ui->checkBoxExcludeTasks, SIGNAL(toggled(bool)),
-             SLOT(slotCheckBoxExcludeTasksChecked(bool)) );
-    connect( m_ui->toolButtonSelectTask, SIGNAL(clicked()),
-             SLOT(slotSelectTask()) );
-    connect( m_ui->toolButtonExcludeTask, SIGNAL(clicked()),
+    connect( m_ui->addExcludeTaskButton, SIGNAL(clicked()),
              SLOT(slotExcludeTask()) );
-    slotCheckboxSubtasksOnlyChecked( m_ui->checkBoxSubTasksOnly->isChecked() );
-    slotCheckBoxExcludeTasksChecked( m_ui->checkBoxExcludeTasks->isChecked() );
+    connect( m_ui->removeExcludeTaskButton, SIGNAL(clicked()),
+             SLOT(slotRemoveExcludedTask()) );
+    connect( m_ui->addIncludeTaskButton, SIGNAL(clicked()),
+             SLOT(slotSelectTask()) );
+    connect( m_ui->removeIncludeTaskButton, SIGNAL(clicked()),
+             SLOT(slotRemoveIncludeTask()) );
 
     new DateEntrySyncer(m_ui->spinBoxStartWeek, m_ui->spinBoxStartYear, m_ui->dateEditStart, 1,  this );
     new DateEntrySyncer(m_ui->spinBoxEndWeek, m_ui->spinBoxEndYear, m_ui->dateEditEnd, 7, this );
@@ -124,50 +121,57 @@ void ActivityReportConfigurationDialog::slotTimeSpanSelected( int index )
     }
 }
 
-void ActivityReportConfigurationDialog::slotCheckboxSubtasksOnlyChecked( bool checked )
-{
-    if ( checked && m_rootTask == 0 ) {
-        slotSelectTask();
-    }
-
-    if ( ! checked ) {
-        m_rootTask = 0;
-        m_ui->labelTaskName->setText( tr( "(All Tasks)" ) );
-    }
-}
-
-void ActivityReportConfigurationDialog::slotCheckBoxExcludeTasksChecked( bool checked )
-{
-    if ( checked && m_rootExcludeTask == 0 ) {
-        slotExcludeTask();
-    }
-
-    if ( ! checked ) {
-        m_rootExcludeTask = 0;
-        m_ui->labelExcludeTaskName->setText( tr( "(No Tasks)" ) );
-    }
-}
-
 void ActivityReportConfigurationDialog::slotSelectTask()
 {
-    if ( selectTask( m_rootTask ) ) {
-        const TaskTreeItem& item = DATAMODEL->taskTreeItem( m_rootTask );
-        m_ui->labelTaskName->setText( DATAMODEL->fullTaskName( item.task() ) );
-    } else {
-        if ( m_rootTask == 0 )
-            m_ui->checkBoxSubTasksOnly->setChecked( false );
+    TaskId taskId;
+    if ( selectTask( taskId ) && !m_rootTasks.contains(taskId)) {
+        const TaskTreeItem& item = DATAMODEL->taskTreeItem( taskId );
+        QListWidgetItem* listItem = new QListWidgetItem( Data::charmIcon(),
+                                                         DATAMODEL->fullTaskName( item.task() ),
+                                                         m_ui->listWidgetIncludeTask );
+        listItem->setData( Qt::UserRole, taskId );
+        m_rootTasks << taskId;
     }
+    m_ui->removeIncludeTaskButton->setEnabled( !m_rootTasks.isEmpty() );
+    m_ui->listWidgetIncludeTask->setEnabled( !m_rootTasks.isEmpty() );
+
 }
 
 void ActivityReportConfigurationDialog::slotExcludeTask()
 {
-    if ( selectTask( m_rootExcludeTask ) ) {
-        const TaskTreeItem& item = DATAMODEL->taskTreeItem( m_rootExcludeTask );
-        m_ui->labelExcludeTaskName->setText( DATAMODEL->fullTaskName( item.task() ) );
-    } else {
-        if ( m_rootExcludeTask == 0 )
-            m_ui->checkBoxExcludeTasks->setChecked( false );
+    TaskId taskId;
+    if ( selectTask( taskId ) && !m_rootExcludeTasks.contains( taskId ) ) {
+        const TaskTreeItem& item = DATAMODEL->taskTreeItem( taskId );
+        QListWidgetItem* listItem = new QListWidgetItem( Data::charmIcon(),
+                                                         DATAMODEL->fullTaskName( item.task() ),
+                                                         m_ui->listWidgetExclude );
+        listItem->setData( Qt::UserRole, taskId );
+        m_rootExcludeTasks << taskId;
     }
+    m_ui->removeExcludeTaskButton->setEnabled( !m_rootExcludeTasks.isEmpty() );
+    m_ui->listWidgetExclude->setEnabled( !m_rootExcludeTasks.isEmpty() );
+}
+
+void ActivityReportConfigurationDialog::slotRemoveExcludedTask()
+{
+    QListWidgetItem* item = m_ui->listWidgetExclude->currentItem();
+    if ( item ) {
+        m_rootExcludeTasks.remove( item->data( Qt::UserRole ).toInt() );
+        delete item;
+    }
+    m_ui->removeExcludeTaskButton->setEnabled( !m_rootExcludeTasks.isEmpty() );
+    m_ui->listWidgetExclude->setEnabled( !m_rootExcludeTasks.isEmpty() );
+}
+
+void ActivityReportConfigurationDialog::slotRemoveIncludeTask()
+{
+    QListWidgetItem* item = m_ui->listWidgetIncludeTask->currentItem();
+    if ( item ) {
+        m_rootTasks.remove( item->data( Qt::UserRole ).toInt() );
+        delete item;
+    }
+    m_ui->removeIncludeTaskButton->setEnabled( !m_rootTasks.isEmpty() );
+    m_ui->listWidgetIncludeTask->setEnabled( !m_rootTasks.isEmpty() );
 }
 
 bool ActivityReportConfigurationDialog::selectTask(TaskId& task)
@@ -186,7 +190,7 @@ void ActivityReportConfigurationDialog::accept()
     QDialog::accept();
 }
 
-void ActivityReportConfigurationDialog::showReportPreviewDialog( QWidget* parent )
+void ActivityReportConfigurationDialog::showReportPreviewDialog()
 {
     QDate start, end;
     const int index = m_ui->comboBox->currentIndex();
@@ -198,16 +202,14 @@ void ActivityReportConfigurationDialog::showReportPreviewDialog( QWidget* parent
         end = m_timespans[index].timespan.second;
     }
 
-    auto report = new ActivityReport( parent );
+    auto report = new ActivityReport();
     report->timeSpanSelection(  m_timespans[index] );
-    report->setReportProperties( start, end, m_rootTask, m_rootExcludeTask );
+    report->setReportProperties( start, end, m_rootTasks, m_rootExcludeTasks );
     report->show();
 }
 
 ActivityReport::ActivityReport( QWidget* parent )
     : ReportPreviewWindow( parent )
-    , m_rootTask( 0 )
-    , m_rootExcludeTask( 0 )
 {
     saveToXmlButton()->hide();
     saveToTextButton()->hide();
@@ -219,12 +221,12 @@ ActivityReport::~ActivityReport()
 {
 }
 
-void ActivityReport::setReportProperties( const QDate& start, const QDate& end, TaskId rootTask, TaskId rootExcludeTask )
+void ActivityReport::setReportProperties( const QDate& start, const QDate& end, QSet<TaskId> rootTasks, QSet<TaskId> rootExcludeTasks )
 {
     m_start = start;
     m_end = end;
-    m_rootTask = rootTask;
-    m_rootExcludeTask = rootExcludeTask;
+    m_rootTasks = rootTasks;
+    m_rootExcludeTasks = rootExcludeTasks;
     slotUpdate();
 }
 
@@ -235,20 +237,21 @@ void ActivityReport::timeSpanSelection( NamedTimeSpan timeSpanSelection )
 
 void ActivityReport::slotUpdate()
 {
-    const QString DateFormat( "yyyy/MM/dd" );
-    const QString TimeFormat( "HH:mm" );
-    const QString DateTimeFormat( "yyyy/MM/dd HH:mm" );
-
     // retrieve matching events:
     EventIdList matchingEvents = DATAMODEL->eventsThatStartInTimeFrame( m_start, m_end );
-    matchingEvents = Charm::eventIdsSortedByStartTime( matchingEvents );
-    if ( m_rootTask != 0 ) {
-        matchingEvents = Charm::filteredBySubtree( matchingEvents, m_rootTask );
+    
+    if( !m_rootTasks.isEmpty() ) {
+        QSet<EventId> filteredEvents;
+        Q_FOREACH( TaskId include,  m_rootTasks ) {
+           filteredEvents |= Charm::filteredBySubtree( matchingEvents, include ).toSet();
+        }
+        matchingEvents = filteredEvents.toList();
     }
+    matchingEvents = Charm::eventIdsSortedByStartTime( matchingEvents );
 
     // filter unproductive events:
-    if ( m_rootExcludeTask != 0 ) {
-        matchingEvents = Charm::filteredBySubtree( matchingEvents, m_rootExcludeTask, true );
+    Q_FOREACH( TaskId exclude,  m_rootExcludeTasks ) {
+        matchingEvents = Charm::filteredBySubtree( matchingEvents, exclude, true );
     }
 
     // calculate total:
@@ -319,10 +322,15 @@ void ActivityReport::slotUpdate()
             paragraph.appendChild( totalsElement );
             body.appendChild( paragraph );
         }
-        if ( m_rootTask != 0 ) {
+        if ( !m_rootTasks.isEmpty() ) {
             QDomElement paragraph = doc.createElement( "p" );
-            const Task& task = DATAMODEL->getTask( m_rootTask );
-            QString rootTaskText = tr( "Activity under task %1" ).arg( DATAMODEL->fullTaskName( task ) );
+            QString rootTaskText = tr( "Activity under tasks:" );
+
+            Q_FOREACH( TaskId taskId, m_rootTasks ) {
+                const Task& task = DATAMODEL->getTask( taskId );
+                rootTaskText.append( QString::fromLatin1( " ( %1 ),").arg( DATAMODEL->fullTaskName( task ) ) );
+            }
+            rootTaskText = rootTaskText.mid(0, rootTaskText.length() - 1 );
             QDomText rootText = doc.createTextNode( rootTaskText );
             paragraph.appendChild( rootText );
             body.appendChild( paragraph );
@@ -442,6 +450,6 @@ void ActivityReport::slotLinkClicked( const QUrl& which )
     default:
         Q_ASSERT( false ); // should not happen
     }
-    setReportProperties( start, end, m_rootTask, m_rootExcludeTask );
+    setReportProperties( start, end, m_rootTasks, m_rootExcludeTasks );
 }
 #include "moc_ActivityReport.cpp"
