@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -48,8 +48,8 @@ private:
     QPushButton *m_asYouWish;
     QPushButton *m_alreadyDone;
     QPushButton *m_later;
-    int m_year;
-    int m_week;
+    int m_year = 0;
+    int m_week = 0;
 };
 
 #endif
