@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -28,7 +28,6 @@ class MakeTemporarilyVisible {
 public:
     explicit MakeTemporarilyVisible( QWidget* widget )
         : m_widget( widget )
-        , m_wasVisible( false )
     {
         Q_ASSERT( m_widget );
         m_wasVisible = m_widget->isVisible();
@@ -43,8 +42,8 @@ public:
         }
     }
 private:
-    QWidget* m_widget;
-    bool m_wasVisible;
+    QWidget* m_widget = {};
+    bool m_wasVisible = false;
 };
 
 #endif
