@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2015-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2015-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Michel Boyer de la Giroday <michel.giroday@kdab.com>
 
@@ -37,7 +37,7 @@ class NotificationPopup : public QDialog
 
 public:
     explicit NotificationPopup( QWidget *parent = nullptr );
-    ~NotificationPopup();
+    ~NotificationPopup() override;
 
     void showNotification( const QString& title, const QString& message );
 
