@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -39,7 +39,7 @@ public:
 
         @param parent parent widget for the preview dialog
      */
-    virtual void showReportPreviewDialog( QWidget* parent ) = 0;
+    virtual void showReportPreviewDialog() = 0;
 };
 
 #endif
