@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
   Author: Mathias Hasselmann <mathias.hasselmann@kdab.com>
@@ -36,8 +36,8 @@
 #include "MessageBox.h"
 #include "MonthlyTimesheet.h"
 #include "MonthlyTimesheetConfigurationDialog.h"
+#include "TemporaryValue.h"
 #include "TimeTrackingView.h"
-#include "Uniquifier.h"
 #include "ViewHelpers.h"
 #include "WeeklyTimesheet.h"
 
@@ -64,6 +64,8 @@
 #include <QFileInfo>
 #include <QMenuBar>
 #include <QMessageBox>
+#include <QScriptEngine>
+#include <QScriptValue>
 #include <QSettings>
 #include <QToolBar>
 #include <QtAlgorithms>
@@ -72,9 +74,6 @@
 
 TimeTrackingWindow::TimeTrackingWindow( QWidget* parent )
     : CharmWindow( tr( "Time Tracker" ), parent )
-    , m_weeklyTimesheetDialog( nullptr )
-    , m_monthlyTimesheetDialog( nullptr )
-    , m_activityReportDialog( nullptr )
     , m_summaryWidget( new TimeTrackingView( this ) )
     , m_billDialog( new BillDialog( this ) )
 {
@@ -92,8 +91,8 @@ TimeTrackingWindow::TimeTrackingWindow( QWidget* parent )
              SLOT(slotBillGone(int)) );
     connect( &m_checkCharmReleaseVersionTimer, SIGNAL(timeout()),
              SLOT(slotCheckForUpdatesAutomatic()) );
-    connect( &m_updateTasksDefinitionsTimer, SIGNAL(timeout()),
-             SLOT(slotSyncTasksAutomatic()) );
+    connect( &m_updateUserInfoAndTasksDefinitionsTimer, SIGNAL(timeout()),
+             SLOT(slotGetUserInfo()) );
 
     //Check every 60 minutes if there are timesheets due
     if (CONFIGURATION.warnUnuploadedTimesheets)
@@ -107,9 +106,9 @@ TimeTrackingWindow::TimeTrackingWindow( QWidget* parent )
     }
 #endif
     //Update tasks definitions once every 24h
-    m_updateTasksDefinitionsTimer.setInterval(24 * 60 * 60 * 1000);
+    m_updateUserInfoAndTasksDefinitionsTimer.setInterval(24 * 60 * 60 * 1000);
     QTimer::singleShot( 1000, this, SLOT(slotSyncTasksAutomatic()) );
-    m_updateTasksDefinitionsTimer.start();
+    m_updateUserInfoAndTasksDefinitionsTimer.start();
 
     toolBar()->hide();
 }
@@ -284,6 +283,7 @@ void TimeTrackingWindow::slotStartEvent( TaskId id )
         QMessageBox::critical( this, tr( "Invalid task" ),
                                tr( "Task '%1' is no longer valid, so can't be started" ).arg( nm ) );
     }
+    ApplicationCore::instance().updateTaskList();
 }
 
 void TimeTrackingWindow::slotStopEvent()
@@ -389,7 +389,7 @@ void TimeTrackingWindow::slotActivityReportPreview( int result )
 void TimeTrackingWindow::showPreview( ReportConfigurationDialog* dialog, int result )
 {
     if ( result == QDialog::Accepted )
-        dialog->showReportPreviewDialog( this );
+        dialog->showReportPreviewDialog();
 }
 
 void TimeTrackingWindow::slotExportToXml()
@@ -485,7 +485,7 @@ void TimeTrackingWindow::slotTasksDownloaded(HttpJob* job_)
         const QString message = tr("Could not download the task list: %1").arg( job->errorString() );
         if ( verbose )
             QMessageBox::critical( this, title, message );
-        else
+        else if ( job->error() != HttpJob::HostNotFound )
             emit showNotification( title, message );
 
         return;
@@ -621,16 +621,12 @@ void TimeTrackingWindow::informUserAboutNewRelease( const QString& releaseVersio
 void TimeTrackingWindow::maybeIdle( IdleDetector* detector )
 {
     Q_ASSERT( detector );
-    static bool inProgress = false;
+    Q_ASSERT( !detector->idlePeriods().isEmpty() );
 
-    if ( inProgress == true ) return;
-    Uniquifier u( &inProgress );
+    if ( m_idleCorrectionDialogVisible )
+        return;
 
-    Q_FOREACH( const IdleDetector::IdlePeriod& p, detector->idlePeriods() ) {
-        qDebug() << "ApplicationCore::slotMaybeIdle: computer might be have been idle from"
-                 << p.first
-                 << "to" << p.second;
-    }
+    const TemporaryValue<bool> tempValue( m_idleCorrectionDialogVisible, true );
 
     // handle idle merging:
     IdleCorrectionDialog dialog( this );
@@ -646,7 +642,6 @@ void TimeTrackingWindow::maybeIdle( IdleDetector* detector )
         // FIXME with this option, we can only change the events to
         // the start time of one idle period, I chose to use the last
         // one:
-        Q_ASSERT( !detector->idlePeriods().isEmpty() );
         const IdleDetector::IdlePeriod period = detector->idlePeriods().last();
 
         Q_FOREACH ( EventId eventId, activeEvents ) {
@@ -706,26 +701,32 @@ void TimeTrackingWindow::importTasksFromDeviceOrFile( QIODevice* device, const Q
             const QString title = success ? tr( "Tasks Import" ) : tr( "Failure setting new tasks" );
             if ( verbose )
                 QMessageBox::information( this, title, detailsText );
-            else
+            else if ( !success )
                 emit showNotification( title, detailsText );
-            getUserInfo();
         }
 
         QSettings settings;
         settings.beginGroup( "httpconfig" );
+        const QString userName = settings.value("username").toString();
         setValueIfNotNull( &settings, QLatin1String("username"), exporter.metadata( QLatin1String("username") ) );
+        const QString currentUserName = settings.value("username").toString();
         setValueIfNotNull( &settings, QLatin1String("portalUrl"), exporter.metadata( QLatin1String("portal-url") ) );
         setValueIfNotNull( &settings, QLatin1String("loginUrl"), exporter.metadata( QLatin1String("login-url") ) );
         setValueIfNotNull( &settings, QLatin1String("timesheetUploadUrl"), exporter.metadata( QLatin1String("timesheet-upload-url") ) );
         setValueIfNotNull( &settings, QLatin1String("projectCodeDownloadUrl"), exporter.metadata( QLatin1String("project-code-download-url") ) );
         settings.endGroup();
         settings.beginGroup( "users" );
-        settings.setValue( QLatin1String("portalUrl"), QLatin1String("https://lotsofcake.kdab.com:443/KdabHome/apps/portal/"));
-        settings.setValue( QLatin1String("loginUrl"), QLatin1String("https://lotsofcake.kdab.com:443/KdabHome/apps/portal/j_security_check"));
+        setValueIfNotNull( &settings, QLatin1String("portalUrl"), exporter.metadata( QLatin1String("portal-url") ) );
+        setValueIfNotNull( &settings, QLatin1String("loginUrl"), exporter.metadata( QLatin1String("login-url") ) );
         settings.setValue( QLatin1String("userInfoDownloadUrl"), QLatin1String("https://lotsofcake.kdab.com/KdabHome/rest/user"));
         settings.endGroup();
 
         ApplicationCore::instance().setHttpActionsVisible( true );
+
+        // update user info in case the user name has changed
+        if ( !currentUserName.isEmpty() && ( currentUserName != userName ) )
+            slotGetUserInfo();
+
     } catch( const CharmException& e ) {
         const QString title = tr( "Invalid Task Definitions" );
         const QString message = e.what().isEmpty()
@@ -739,50 +740,55 @@ void TimeTrackingWindow::importTasksFromDeviceOrFile( QIODevice* device, const Q
     }
 }
 
-void  TimeTrackingWindow::getUserInfo()
+void  TimeTrackingWindow::slotGetUserInfo()
 {
     if (!HttpJob::credentialsAvailable())
             return;
 
     QSettings settings;
     settings.beginGroup( "httpconfig" );
-    m_user = settings.value("username").toString();
+    const QString userName = settings.value( "username" ).toString();
     settings.endGroup();
 
     settings.beginGroup( "users" );
-    settings.setValue( QLatin1String("userInfoDownloadUrl"), QLatin1String("https://lotsofcake.kdab.com/KdabHome/rest/user?user=") + m_user );
+    settings.setValue( QLatin1String( "userInfoDownloadUrl" ), QLatin1String( "https://lotsofcake.kdab.com/KdabHome/rest/user?user=" ) + userName );
     settings.endGroup();
 
-    GetUserInfoJob *client = new GetUserInfoJob(this,"users");
-    client->schema() = m_user;
-    HttpJobProgressDialog* dialog = new HttpJobProgressDialog( client, this );
-    dialog->setWindowTitle( tr("Downloading weekly hours") );
+    GetUserInfoJob *client = new GetUserInfoJob( this, "users" );
+    client->setSchema( userName );
     connect( client, SIGNAL(finished(HttpJob*)), this, SLOT(slotUserInfoDownloaded(HttpJob*)) );
     client->start();
 }
 
 void TimeTrackingWindow::slotUserInfoDownloaded( HttpJob* job_ )
 {
+    // getUserInfo done -> sync task
+    slotSyncTasksAutomatic();
+
     GetUserInfoJob * job = qobject_cast<GetUserInfoJob *>( job_ );
     Q_ASSERT( job );
     if ( job->error() == HttpJob::Canceled )
         return;
 
     if ( job->error() ) {
-        QMessageBox::critical( this, tr("Error"), tr("Could not download weekly hours: %1").arg( job->errorString() ) );
+        QMessageBox::critical( this, tr( "Error" ), tr( "Could not download weekly hours: %1" ).arg( job->errorString() ) );
         return;
     }
 
     QByteArray readData = job->userInfo();
-    int index = readData.indexOf("weeklyHours");
-    index += 13;
-    QString weeklyH = readData.mid(index,2).trimmed();
-    if (weeklyH.length() != 2 )
-        weeklyH = "40";
+    const QString data = readData.constData();
+
+    QScriptEngine engine;
+    QScriptValue result = engine.evaluate( '(' + data + ')' );
+    QScriptValue entries = result.property( "hrInfo" ).property( "weeklyHours" );
+    QString weeklyHours = QString::number( entries.toVariant().toDouble(), 'g', 2 );
+
+    if ( weeklyHours.isEmpty() )
+        weeklyHours = "40";
+
     QSettings settings;
     settings.beginGroup( "users" );
-    settings.setValue( QLatin1String("weeklyhours"), weeklyH);
+    settings.setValue( QLatin1String( "weeklyhours" ), weeklyHours );
     settings.endGroup();
-
 }
 #include "moc_TimeTrackingWindow.cpp"
