@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -32,7 +32,7 @@ class TrayIcon : public QSystemTrayIcon
 
 public:
     explicit TrayIcon(QObject* parent = nullptr);
-    virtual ~TrayIcon();
+    ~TrayIcon() override;
 
 private Q_SLOTS:
     void slotActivated(QSystemTrayIcon::ActivationReason);
