@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Frank Osterfeld <frank.osterfeld@kdab.com>
 
@@ -166,7 +166,7 @@ void WeeklyTimesheetConfigurationDialog::accept()
     QDialog::accept();
 }
 
-void WeeklyTimesheetConfigurationDialog::showReportPreviewDialog( QWidget* parent )
+void WeeklyTimesheetConfigurationDialog::showReportPreviewDialog()
 {
     QDate start, end;
     int index = m_ui->comboBoxWeek->currentIndex();
@@ -180,7 +180,7 @@ void WeeklyTimesheetConfigurationDialog::showReportPreviewDialog( QWidget* paren
         end = m_weekInfo[index].timespan.second;
     }
     bool activeOnly = m_ui->checkBoxActiveOnly->isChecked();
-    auto report = new WeeklyTimeSheetReport( parent );
+    auto report = new WeeklyTimeSheetReport();
     report->setReportProperties( start, end, m_rootTask, activeOnly );
     report->show();
 }
@@ -265,12 +265,11 @@ void WeeklyTimesheetConfigurationDialog::slotSelectTask()
 
 WeeklyTimeSheetReport::WeeklyTimeSheetReport( QWidget* parent )
     : TimeSheetReport( parent )
-    , m_weekNumber( 0 )
-    , m_yearOfWeek( 0 )
 {
     QPushButton* upload = uploadButton();
     connect( upload, SIGNAL(clicked()), SLOT(slotUploadTimesheet()) );
     connect( this, SIGNAL(anchorClicked(QUrl)), SLOT(slotLinkClicked(QUrl)) );
+
     if (!HttpJob::credentialsAvailable())
         upload->hide();
 }
