@@ -3,7 +3,7 @@
 
   This file is part of Charm, a task-based time tracking application.
 
-  Copyright (C) 2007-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2007-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
 
   Author: Mirko Boehm <mirko.boehm@kdab.com>
 
@@ -43,7 +43,7 @@ private slots:
     void cleanupTestCase();
 
 private:
-    CharmDataModel* m_referenceModel;
+    CharmDataModel* m_referenceModel = nullptr;
 };
 
 #endif
